PyPika - Python Query Builder
=============================

.. include:: ../README.rst
   :start-after: _intro_start:
   :end-before:  _intro_end:

.. include:: ../README.rst
   :start-after: _appendix_start:
   :end-before:  _appendix_end:

.. include:: ../README.rst
   :start-after: _contributing_start:
   :end-before:  _contributing_end:

Contents
--------

.. toctree::
    :maxdepth: 2

    1_installation
    2_tutorial
    3_advanced
    4_extending
    5_reference
    6_contributing

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`


.. include:: ../README.rst
   :start-after: _license_start:
   :end-before:  _license_end:

.. include:: ../README.rst
   :start-after: _available_badges_start:
   :end-before:  _available_badges_end:

